@@ -1,35 +1,43 @@
-import os 
-import sys 
-import json 
-import logging 
+import os
+import sys
+import json
+import logging
 import traceback
 
-logger = logging.getLogger('app') 
+logger = logging.getLogger('app')
 
-def should_skip(name): 
+def should_skip(name):
 
-    return (name.startswith(".") or 
-            name == "__pycache__") 
+    return (name.startswith(".") or
+            name == "__pycache__")
 
-def load_customer_assets(context={}): 
+def load_customer_assets(context={}):
     """
     Go through the customer directories and add the assets from all
-    installed customer modules. 
+    installed customer modules.
 
-    The ENRICH_CUSTOMERS looks like system path, and it is processed 
-    as such. It gives priority to the modules earlier in the path 
+    The ENRICH_CUSTOMERS looks like system path, and it is processed
+    as such. It gives priority to the modules earlier in the path
     than later. Typically you create a run directory and prepend
     that run directory in front of the standard directory.
     """
 
-    assets = {} 
+    assets = {}
 
-    # Check if the environment is correctly configured 
+    # Check if the environment is correctly configured
     enrich_customers = context.get('ENRICH_CUSTOMERS',
                                    os.environ.get('ENRICH_CUSTOMERS',
                                                   None))
 
-    if enrich_customers is None: 
+    if enrich_customers is None:
+        enrich_root = context.get('ENRICH_ROOT',
+                                  os.environ.get('ENRICH_ROOT',
+                                                 None))
+        if enrich_root is not None:
+            enrich_customers = os.path.join(enrich_root, "customers")
+
+
+    if enrich_customers is None:
         logger.error("Customer root is missing : {}".format(enrich_customers))
         return assets
 
@@ -52,7 +60,7 @@ def load_customer_assets(context={}):
         customer_root = os.path.dirname(customer_dir)
 
         if not os.path.isdir(customer_dir) or should_skip(customer):
-            continue 
+            continue
 
         enrichfile = os.path.join(customer_dir, 'enrich.json')
         if not os.path.exists(enrichfile):
@@ -65,10 +73,10 @@ def load_customer_assets(context={}):
             logger.debug("Invalid enrichfile. Skipping customer: {}".format(customer))
             continue
 
-        if not enrich.get('enable', True): 
+        if not enrich.get('enable', True):
             logger.debug("Disabled customer. Skipping customer: {}".format(customer))
-            continue 
-            
+            continue
+
         for usecase in os.listdir(customer_dir):
             """
             Each usecase within the customer organization
@@ -99,36 +107,36 @@ def load_customer_assets(context={}):
             #        /pkg
             #            /assets
             #        /assets
-            
+
             for assetsdir in [os.path.join(usecasedir, 'pkg', 'assets'),
                               os.path.join(usecasedir, 'assets')]:
-                if not os.path.exists(assetsdir): 
-                    continue 
-    
-                for a in os.listdir(assetsdir): 
-                    if should_skip(a): 
-                        continue 
+                if not os.path.exists(assetsdir):
+                    continue
+
+                for a in os.listdir(assetsdir):
+                    if should_skip(a):
+                        continue
 
                     for pkgdir in [ os.path.join(assetsdir, a, a),
-                                    os.path.join(assetsdir, a, 'src', a)]: 
+                                    os.path.join(assetsdir, a, 'src', a)]:
 
                         if not os.path.exists(pkgdir):
                             continue
-                    
+
                         libdir = os.path.abspath(os.path.dirname(pkgdir))
-                        if libdir not in sys.path: 
+                        if libdir not in sys.path:
                             sys.path.append(libdir)
 
                         assets[a] = {
                             'fullpath': os.path.join(libdir, a),
                             'relpath': os.path.relpath(os.path.join(libdir, a),
-                                                       customer_root),                     
+                                                       customer_root),
                             'organization': enrich['org']['name'],
                             'usecase': usecase,
                             'customer': customer
                         }
 
-    return assets 
+    return assets
 
 def find_usecase(path):
     """
